@@ -28,6 +28,23 @@ TRANSACTION_TYPES = [
     "OTHER",  # Other
 ]
 
+INVEST_TRANSACTION_TYPES = [
+    "BUYSTOCK",
+    "BUYDEBT",
+    "SELLSTOCK",
+    "SELLDEBT",
+    "INCOME",
+]
+
+INVEST_TRANSACTION_TYPES_DETAILED = [
+    "BUY",
+    "BUYTOCOVER",  # end short sale
+    "SELL",
+    "SELLSHORT",  # open short sale
+    "DIV",  # only for INCOME
+    "INTEREST",  # only for INCOME
+]
+
 ACCOUNT_TYPE = [
     "CHECKING",  # Checking
     "SAVINGS",  # Savings
@@ -48,9 +65,11 @@ class Statement(Printable):
     """Statement object containing statement items"""
 
     lines: List["StatementLine"]
+    invest_lines: List["InvestStatementLine"]
 
     currency: Optional[str] = None
     bank_id: Optional[str] = None
+    broker_id: Optional[str] = None
     account_id: Optional[str] = None
     # Type of account, must be one of ACCOUNT_TYPE
     account_type: Optional[str] = None
@@ -69,6 +88,7 @@ class Statement(Printable):
         account_type: str = "CHECKING",
     ) -> None:
         self.lines = []
+        self.invest_lines = []
         self.bank_id = bank_id
         self.account_id = account_id
         self.currency = currency
@@ -120,6 +140,13 @@ class StatementLine(Printable):
     # Optional BankAccount instance
     bank_account_to: Optional["BankAccount"] = None
 
+    # Currency this line is expressed in (if different from statement
+    # currency). Available since 0.7.2
+    currency: Optional["Currency"] = None
+
+    # Original amount and the original (foreign) currency. Available since 0.7.2
+    orig_currency: Optional["Currency"] = None
+
     def __init__(
         self, id: str = None, date: datetime = None, memo: str = None, amount: D = None
     ) -> None:
@@ -149,8 +176,11 @@ class StatementLine(Printable):
 
     def assert_valid(self) -> None:
         """Ensure that fields have valid values"""
-        assert self.trntype in TRANSACTION_TYPES, (
-            "trntype must be one of %s" % TRANSACTION_TYPES
+        assert (
+            self.trntype in TRANSACTION_TYPES
+        ), "trntype %s is not valid, must be one of %s" % (
+            self.trntype,
+            TRANSACTION_TYPES,
         )
 
         if self.bank_account_to:
@@ -159,6 +189,102 @@ class StatementLine(Printable):
         assert self.id or self.check_no or self.refnum
 
 
+class Currency(Printable):
+    """CURRENCY and ORIGCURRENCY aggregates from OFX
+
+    See section 5.2 from OFX spec version 2.2.
+    """
+
+    # ISO-4217 3-letter currency identifier
+    symbol: str
+    # Ratio of statement currency to `symbol` currency
+    rate: Optional[D]
+
+    def __init__(self, symbol: str, rate: D = None) -> None:
+        self.symbol = symbol
+        self.rate = rate
+
+
+class InvestStatementLine(Printable):
+    """Invest statement line data. """
+
+    id: Optional[str]
+    # Date transaction was posted to account
+    date: Optional[datetime]
+    memo: Optional[str]
+
+    # ID or ticker of underlying security
+    security_id: Optional[str]
+    # Transaction type, must be one of INVEST_TRANSACTION_TYPES
+    trntype: Optional[str]
+    # More detailed information about transaction, must be one of INVEST_TRANSACTION_TYPES_DETAILED
+    trntype_detailed: Optional[str]
+
+    # Amount of transaction
+    amount: Optional[D]
+    fees: Optional[D] = None
+    unit_price: Optional[D] = None  # required for buy/sell transactions
+    units: Optional[D] = None  # required for buy/sell transactions
+
+    def __init__(
+        self,
+        id: str = None,
+        date: datetime = None,
+        memo: str = None,
+        trntype: str = None,
+        trntype_detailed: str = None,
+        security_id: str = None,
+        amount: D = None,
+    ) -> None:
+        self.id = id
+        self.date = date
+        self.memo = memo
+        self.trntype = trntype
+        self.trntype_detailed = trntype_detailed
+        self.security_id = security_id
+        self.amount = amount
+
+    def __str__(self) -> str:
+        return """
+            ID: %s, date: %s, trntype: %s, trntype_detailed: %s, security_id: %s, units: %s, unit_price: %s, amount: %s, fees: %s
+            memo: %s
+            """ % (
+            self.id,
+            self.date,
+            self.trntype,
+            self.trntype_detailed,
+            self.security_id,
+            self.units,
+            self.unit_price,
+            self.amount,
+            self.fees,
+            self.memo,
+        )
+
+    def assert_valid(self) -> None:
+        """Ensure that fields have valid values"""
+        assert (
+            self.trntype in INVEST_TRANSACTION_TYPES
+        ), "trntype %s is not valid, must be one of %s" % (
+            self.trntype,
+            INVEST_TRANSACTION_TYPES,
+        )
+
+        assert (
+            self.trntype_detailed in INVEST_TRANSACTION_TYPES_DETAILED
+        ), "trntype_detailed %s is not valid, must be one of %s" % (
+            self.trntype_detailed,
+            INVEST_TRANSACTION_TYPES_DETAILED,
+        )
+
+        assert self.id
+        assert self.security_id
+        assert self.amount
+
+        assert self.trntype == "INCOME" or self.units
+        assert self.trntype == "INCOME" or self.unit_price
+
+
 class BankAccount(Printable):
     """Structure corresponding to BANKACCTTO and BANKACCTFROM elements from OFX
 
@@ -264,5 +390,5 @@ def recalculate_balance(stmt: Statement) -> None:
 
     stmt.start_balance = stmt.start_balance or D(0)
     stmt.end_balance = stmt.start_balance + total_amount
-    stmt.start_date = min(sl.date for sl in stmt.lines)
-    stmt.end_date = max(sl.date for sl in stmt.lines)
+    stmt.start_date = min(sl.date for sl in stmt.lines if sl.date is not None)
+    stmt.end_date = max(sl.date for sl in stmt.lines if sl.date is not None)
