@@ -4,7 +4,7 @@ from decimal import Decimal
 
 from datetime import datetime
 
-from ofxstatement.statement import Statement, StatementLine, BankAccount
+from ofxstatement.statement import Statement, StatementLine, BankAccount, Currency
 from ofxstatement import ofx
 
 SIMPLE_OFX = """<?xml version="1.0" ?>
@@ -66,6 +66,13 @@ NEWFILEUID:NONE
                             <ACCTID>LT1232</ACCTID>
                             <ACCTTYPE>CHECKING</ACCTTYPE>
                         </BANKACCTTO>
+                        <CURRENCY>
+                            <CURSYM>USD</CURSYM>
+                        </CURRENCY>
+                        <ORIG_CURRENCY>
+                            <CURSYM>EUR</CURSYM>
+                            <CURRATE>3.45</CURRATE>
+                        </ORIG_CURRENCY>
                     </STMTTRN>
                 </BANKTRANLIST>
                 <LEDGERBAL>
@@ -96,6 +103,8 @@ class OfxWriterTest(TestCase):
         line.payee = ""
         line.bank_account_to = BankAccount("SNORAS", "LT1232")
         line.bank_account_to.branch_id = "VNO"
+        line.currency = Currency("USD")
+        line.orig_currency = Currency("EUR", Decimal("3.4543"))
         statement.lines.append(line)
 
         # Create writer:
@@ -105,3 +114,43 @@ class OfxWriterTest(TestCase):
         writer.genTime = datetime(2012, 3, 3, 0, 0, 0)
 
         assert prettyPrint(writer.toxml()) == SIMPLE_OFX
+
+    def test_ofxWriter_pretty(self) -> None:
+        # GIVEN
+        statement = Statement("BID", "ACCID", "LTL")
+        writer = ofx.OfxWriter(statement)
+        writer.genTime = datetime(2021, 9, 3, 0, 0, 0)
+
+        # WHEN
+        xml = writer.toxml(pretty=True)
+
+        # THEN
+        expected = [
+            "<!-- ",
+            "OFXHEADER:100",
+            "DATA:OFXSGML",
+            "VERSION:102",
+            "SECURITY:NONE",
+            "ENCODING:UTF-8",
+            "CHARSET:NONE",
+            "COMPRESSION:NONE",
+            "OLDFILEUID:NONE",
+            "NEWFILEUID:NONE",
+            "-->",
+            "",
+            "<OFX>",
+            "  <SIGNONMSGSRSV1>",
+            "    <SONRS>",
+            "      <STATUS>",
+            "        <CODE>0</CODE>",
+            "        <SEVERITY>INFO</SEVERITY>",
+            "      </STATUS>",
+            "      <DTSERVER>20210903000000</DTSERVER>",
+            "      <LANGUAGE>ENG</LANGUAGE>",
+            "    </SONRS>",
+            "  </SIGNONMSGSRSV1>",
+            "</OFX>",
+            "",
+        ]
+
+        assert xml.split("\n") == expected
