@@ -18,10 +18,13 @@ log = logging.getLogger(__name__)
 
 
 @contextlib.contextmanager
-def smart_open(filename: str = None):
+def smart_open(filename: str = None, encoding: str = None):
     """See https://stackoverflow.com/questions/17602878/how-to-handle-both-with-open-and-sys-stdout-nicely"""  # noqa
     if filename and filename != "-":
-        fh = open(filename, "w")
+        # encoding is required in cases when OS defaults to encoding which
+        # doesn't support unicode characters, for example Windows defaults to
+        # 'cp1252'
+        fh = open(filename, "w", encoding=encoding)
     else:
         fh = sys.stdout
 
@@ -76,6 +79,13 @@ def make_args_parser() -> argparse.ArgumentParser:
             "have no config file."
         ),
     )
+    parser_convert.add_argument(
+        "-p",
+        "--pretty",
+        action="store_true",
+        default=False,
+        help="produce pretty xml with nested tags properly indented.",
+    )
     parser_convert.add_argument("input", help="input file to process")
     parser_convert.add_argument(
         "output",
@@ -175,9 +185,9 @@ def convert(args: argparse.Namespace) -> int:
         log.error("Statement validation error: %s" % (e.message))
         return 2  # Validation error
 
-    with smart_open(args.output) as out:
+    with smart_open(args.output, settings.get("encoding", None)) as out:
         writer = ofx.OfxWriter(statement)
-        out.write(writer.toxml())
+        out.write(writer.toxml(pretty=args.pretty))
 
     log.info("Conversion completed: %s" % args.input)
     return 0  # success
